//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

namespace Neo.ApplicationFramework.Generated
{
    using System.Windows.Forms;
    using System;
    using System.Drawing;
    using Neo.ApplicationFramework.Tools;
    using Neo.ApplicationFramework.Common.Graphics.Logic;
    using Neo.ApplicationFramework.Controls;
    using Neo.ApplicationFramework.Interfaces;
    
    
    public partial class SchedulerEditor
    {
		#region Events
		void Screen6_Scheduler_Opened(System.Object sender, System.EventArgs e)
		{
			Globals.SchedulerUtils.RestoreSchedulerJobs();
			FillCmbJobPeriods();
			FillCmbAvailableJobs();
			
			CheckForSdCard();
			
		}
		void CMB_AvailableJobs_SelectionChanged(System.Object sender, System.EventArgs e)
		{
			RefreshJob();
		}
		void Btn_RestoreJobs_Click(System.Object sender, System.EventArgs e)
		{
			Globals.SchedulerUtils.RestoreSchedulerJobs();
			RefreshJob();
		}			
			
		void Btn_UndoChanges_Click(System.Object sender, System.EventArgs e)
		{
			RefreshJob();	
		}
		
		void Btn_ApplyChanges_Click(System.Object sender, System.EventArgs e)
		{
			ApplyJobChanges();
		}
		void Btn_SafeJobs_Click(System.Object sender, System.EventArgs e)
		{
			if(Globals.SchedulerUtils.SdCardExists())
			{
				try
				{
					Globals.SchedulerUtils.SafeSchedulerJobs();
				}
				catch (Exception err)
				{
					MessageBox.Show(err.Message);
				}
			}
			else
			{
				MessageBox.Show("Sorry. Es wurde keine SD-Card gefunden.");
			}
		}
		
		void AN_JobStartDate_InputValueChanged(System.Object sender, Neo.ApplicationFramework.Interfaces.Events.ValueChangedEventArgs e)
		{
			Globals.SchedulerUtils.StartDate = this.AN_JobStartDate.Value.ToString();
			this.AN_JobStartDay.Value = Globals.SchedulerUtils.StartDay;
		}
		
		void AN_JobStartTime_InputValueChanged(System.Object sender, Neo.ApplicationFramework.Interfaces.Events.ValueChangedEventArgs e)
		{
			Globals.SchedulerUtils.StartTime = this.AN_JobStartTime.Value.ToString();
			this.AN_JobDuration.Value = Globals.SchedulerUtils.Duration;
		}			
		void AN_JobEndTime_InputValueChanged(System.Object sender, Neo.ApplicationFramework.Interfaces.Events.ValueChangedEventArgs e)
		{
			Globals.SchedulerUtils.EndTime = this.AN_JobEndTime.Value.ToString();
			this.AN_JobDuration.Value = Globals.SchedulerUtils.Duration;	
		}		
		

		#endregion Events
		
		#region Helper Methods
		
		void FillCmbJobPeriods()
		{
			foreach(string str in Globals.SchedulerUtils.periods)
			{
				this.CMB_JobPeriod.Items.Add(str);
			}
		}

		void FillCmbAvailableJobs()
		{
			string[] jobNames = new string[]{};
			Globals.SchedulerUtils.GetSchedulerJobs(ref jobNames);
			foreach (string jobName in jobNames)
			{
				this.CMB_AvailableJobs.Items.Add(jobName);
			}
			this.CMB_AvailableJobs.SelectedIndex = 0;
		}
		
		
		private void RefreshJob()
		{
			Globals.SchedulerUtils.GetSchedulerJobByIndex(this.CMB_AvailableJobs.SelectedIndex);
			
			this.CMB_JobPeriod.SelectedIndex = Globals.SchedulerUtils.iPeriod;
			this.AN_JobStartDate.Value 	= Globals.SchedulerUtils.StartDate;
			this.AN_JobStartDay.Value	= Globals.SchedulerUtils.StartDay;
			this.AN_JobStartTime.Value 	= Globals.SchedulerUtils.StartTime;
			this.AN_JobDuration.Value 	= Globals.SchedulerUtils.Duration;
			this.AN_JobEndTime.Value	= Globals.SchedulerUtils.EndTime;
		
			if (Globals.SchedulerUtils.StopTimeEnabled == "True")
			{
				Globals.Tags.SchedJob_StopTimeEnabled.Value = 1;
			}
			else
			{
				Globals.Tags.SchedJob_StopTimeEnabled.Value = 0;
			}
			
			
			this.AN_JobStopDate.Value 	= Globals.SchedulerUtils.StopDate;
			this.AN_JobStopTime.Value 	= Globals.SchedulerUtils.StopTime;
			
			
			CheckForSdCard();
		}

		private void ApplyJobChanges()
		{
			Globals.SchedulerUtils.Period = this.CMB_JobPeriod.Text.ToString();
			Globals.SchedulerUtils.iPeriod = this.CMB_JobPeriod.SelectedIndex;
			Globals.SchedulerUtils.StartDate = this.AN_JobStartDate.Value.ToString();
			Globals.SchedulerUtils.StartTime = this.AN_JobStartTime.Value.ToString();
			Globals.SchedulerUtils.Duration = this.AN_JobDuration.Value.ToString();
			Globals.SchedulerUtils.StopTimeEnabled = this.CMB_JobStopTimeEnabled.Text.ToString();	
			Globals.SchedulerUtils.StopDate = this.AN_JobStopDate.Value.ToString();
			Globals.SchedulerUtils.StopTime = this.AN_JobStopTime.Value.ToString();
			
			Globals.SchedulerUtils.ApplySchedJobChanges(this.CMB_AvailableJobs.SelectedIndex);
			
		}
		
		
		private void CheckForSdCard()
		{
			bool sdCardExist;
			sdCardExist = Globals.SchedulerUtils.SdCardExists();
			this.Btn_SdCardPresent.Visible = !sdCardExist;
			
			this.AN_JobStartDate.IsEnabled = sdCardExist;
			this.AN_JobStartTime.IsEnabled = sdCardExist;
			this.AN_JobEndTime.IsEnabled = sdCardExist;
			
			this.CMB_JobPeriod.IsEnabled = sdCardExist;
			this.CMB_JobStopTimeEnabled.IsEnabled = sdCardExist;
		}
		
		#endregion Helper Methods			
		void Btn_SdCardPresent_Click(System.Object sender, System.EventArgs e)
		{
			CheckForSdCard();
		}			
    }
}
