//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

namespace Neo.ApplicationFramework.Generated
{
	using System.Windows.Forms;
	using System;
	using System.IO;
	using System.Drawing;
	using Neo.ApplicationFramework.Tools;
	using Neo.ApplicationFramework.Common.Graphics.Logic;
	using Neo.ApplicationFramework.Controls;
	using Neo.ApplicationFramework.Interfaces;
	using System.Collections.Generic;
    
    
	public partial class SchedulerUtils
	{
		private string name;
		private string period;
		private int iperiod;
		private string startDate;
		private string startDay;
		private string startTime;
		private string duration;
		private string endTime;
		private string stopTimeEnabled;
		private string stopDate;
		private string stopTime;
		
		
		public string[] periods = {"Once", "EveryMinute", "EveryHour", "Daily", "Weekly", "Monthly", "Yearly"};

		
		private string path = @"\Storage Card\SchedulerJobs";	// Path on SD-Card	
		
		Tools.Scheduler.SchedulerJobs jobs = new Tools.Scheduler.SchedulerJobs(Globals.Scheduler);
		Interfaces.ISchedulerJob m_job;
		
		
		
		/// <summary>
		/// SafeSchedulerJobs
		/// Safes the properties of every available scheduler job within a text file.
		/// The storage path can be selected by the global variable "path"
		/// </summary>
		/// <returns></returns>
		public void SafeSchedulerJobs()
		{
			// Create Directory
			try 
			{
				// Determine whether the directory exists. 
				if (!Directory.Exists(path)) 
				{
					DirectoryInfo di = Directory.CreateDirectory(path);
				}	
				jobs = Globals.Scheduler.SchedulerJobs;
				int i = 0; // Counter for SchedulerJobs
			
				foreach (Interfaces.ISchedulerJob job in jobs)
				{
					string jobInfo = 	"Name: " 		+ job.Name + Environment.NewLine;
					jobInfo = jobInfo + "Period: " 		+ job.Period.ToString() + Environment.NewLine;
					jobInfo = jobInfo + "Start Date: " 	+ job.StartDate.ToShortDateString() + Environment.NewLine;
					jobInfo = jobInfo + "Start Time: " 	+ job.StartTime.ToShortTimeString() + Environment.NewLine;
					jobInfo = jobInfo + "Duration: " 	+ job.Duration.ToString() + Environment.NewLine;	
					jobInfo = jobInfo + "Stop Time Enabled: " + job.StopTimeEnabled.ToString() + Environment.NewLine;
					jobInfo = jobInfo + "Stop Date: "	+ job.StopDate.ToShortDateString() + Environment.NewLine;
					jobInfo = jobInfo + "Stop Time: "	+ job.StopTime.ToShortTimeString() + Environment.NewLine;
				
					System.IO.StreamWriter file = new System.IO.StreamWriter(path + "\\job_" + job.Name + ".txt", false); // Falls File bereits existiert, überschreibe es
					file.WriteLine(jobInfo); 
					file.Close();
					i++;
				}
			} 
			catch (Exception err) 
			{
				MessageBox.Show("The process of creating the path on SD-Card failed: {0}", err.ToString());
			}
		}
		
		/// <summary>
		/// RestoreSchedulerJobs
		/// Restores the properties of available scheduler jobs from a persistant memory source.
		/// The path is defined by the global variable "path"
		/// </summary>
		/// <returns></returns>
		public void RestoreSchedulerJobs()
		{

			// Check if Memory Device is present
			if(!SdCardExists())
			{
				MessageBox.Show("No SD-Card in iX Panel!\n\r No Scheduler-Recovery possible.");
				return;
			}
			try
			{
				jobs = Globals.Scheduler.SchedulerJobs;
				int i = 0; // Counter for SchedulerJobs
				string mypath;
			
				foreach (Interfaces.ISchedulerJob job in jobs)
				{
					mypath = path + "\\job_" + jobs[i].Name + ".txt";
					if (File.Exists(mypath)) 
					{
						System.IO.StreamReader myfile = new System.IO.StreamReader(mypath);
						
						List<string> jobData = new List<string>();
						
						string line;
						int found = 0;
						while ((line = myfile.ReadLine()) != null)
						{
							found = line.IndexOf(":");	// Find ':' in String and cut Text in front
							jobData.Add(line.Substring(found + 1)); // Add to list.
						}
						myfile.Close();

						// Remove Whitespaces in Strings
						for (int j = 0; j < jobData.Count; j++)
						{
							jobData[j] = jobData[j].Replace(" ", string.Empty);
						}
						jobs[i].Name 		= jobData[0];
						
						int Index = Array.IndexOf(periods, jobData[1].ToString());//period);
						jobs[i].Period = (Interfaces.SchedulerJobPeriods)Index;
						jobs[i].StartDate 	= DateTime.Parse(jobData[2]);
						jobs[i].StartTime 	= DateTime.Parse(jobData[3]);
						jobs[i].Duration 	= TimeSpan.Parse(jobData[4]);
						jobs[i].StopTimeEnabled =  Boolean.Parse(jobData[5]);
						jobs[i].StopDate	= DateTime.Parse(jobData[6]);
						jobs[i].StopTime	= DateTime.Parse(jobData[7]);
					}
					else
					{
						MessageBox.Show("File does not exist: "+ mypath);
					}
					i++;
				}
				
			}
			catch (Exception err)
			{
				MessageBox.Show("Error during Restore: " + err.Message);
			}
		}

		/// <summary>
		/// ApplySchedJobChanges
		/// Applies the changed properties to the according scheduler job.
		/// Caution: the changed properties are lost in case of cycling power. Therefore safe the job properties
		/// in a persistant memory with SafeSchedulerJobs()
		/// </summary>
		/// <returns></returns>
		public void ApplySchedJobChanges(int Index)
		{
			if (Index < 0)
			{
				return;
			}
			m_job = Globals.Scheduler.SchedulerJobs[Index];
			
			try
			{
				
				//m_job.DescriptiveName 	= name; // <-- JobName is ReadOnly!!!
				m_job.Period 			= (Interfaces.SchedulerJobPeriods)Array.IndexOf(periods, period);	
				m_job.StartDate 		= DateTime.Parse(startDate);
				m_job.StartTime 		= DateTime.Parse(startTime);
				m_job.Duration 			= TimeSpan.Parse(duration);
				m_job.Duration 			= DateTime.Parse(endTime).Subtract(DateTime.Parse(startTime));
				m_job.StopTimeEnabled 	= Boolean.Parse(stopTimeEnabled);
				m_job.StopDate 			= DateTime.Parse(stopDate);
				m_job.StopTime 			= DateTime.Parse(stopTime);	
			}
			catch (Exception err)
			{
				MessageBox.Show("ApplySchedJobChanges: " + err.Message);
			}
		}

		/// <summary>
		/// GetSchedulerJobs
		/// Retrieves a string array contaning Job Names with avaliable Jobs
		/// </summary>
		/// <param name="JobNames">string[] of jobnames</param>
		/// <returns></returns>
		public void GetSchedulerJobs(ref string[]JobNames)
		{
			try
			{
				//Move jobs to container to work with
				jobs = Globals.Scheduler.SchedulerJobs;
			
				//Code below shows how to extract a given (index) job within the collection 						
				Array.Resize(ref JobNames, jobs.Count);
			
				//Iterates through the collection and gets the names of each avaliable schedulerjob
				int i = 0;
				foreach (Interfaces.ISchedulerJob job in jobs)
				{
					JobNames[i] = (job.Name);
					i++;
				}
			}
			catch (Exception err)
			{
				MessageBox.Show("GetSchedulerJobs: " + err.Message);
			}
		}


		
		/// <summary>
		/// GetSchedulerJobByIndex
		/// Retrieves all needed properties of the selected job
		/// </summary>
		/// <param name="JobNames">string[] of jobnames</param>
		/// <returns></returns>		
		public void GetSchedulerJobByIndex(int Index)
		{		
			jobs = Globals.Scheduler.SchedulerJobs;
			m_job = jobs[Index];
			
			name 		= m_job.Name;
			period 		= m_job.Period.ToString();
			iperiod = Array.IndexOf(periods, period);
			
			startDate 	= m_job.StartDate.ToShortDateString();
			startDay	= m_job.Day.ToString();
			startTime 	= m_job.StartTime.ToShortTimeString();
			duration 	= m_job.Duration.ToString();
			stopTimeEnabled = m_job.StopTimeEnabled.ToString();
			stopDate 	= m_job.StopDate.ToShortDateString();
			stopTime 	= m_job.StopTime.ToShortTimeString();

			endTime = DateTime.Parse(startTime).Add(TimeSpan.Parse(duration)).ToShortTimeString();
		}
		
		
		
		#region Properties
		public string Name
		{
			get { return name; }
			//set { name = value; }
		}	
		public string Period
		{
			get { return period; }
			set { period = value; }
		}
		public int iPeriod
		{
			get { return iperiod; }
			set { iperiod = value; }
		}
		public string StartDate {
			get { return startDate; }
			set 
			{ 
				startDate = value; 
				DateTime dateValue;
				dateValue = DateTime.Parse(startDate);
				startDay = dateValue.DayOfWeek.ToString();
			}
		}
		public string StartDay {
			get { return startDay; }	
		}
		public string StartTime 
		{
			get { return startTime; }
			set 
			{ 
				startTime = value; 
				duration = DateTime.Parse(endTime).Subtract(DateTime.Parse(startTime)).ToString();
			}
		}
		public string Duration
		{
			get { return duration; }
			set 
			{ 
				duration = value;
				endTime = DateTime.Parse(startTime).Add(TimeSpan.Parse(duration)).ToString();
			}
		}
		public string EndTime
		{
			get { return endTime; }
			set 
			{ 
				endTime = value;
				duration = DateTime.Parse(endTime).Subtract(DateTime.Parse(startTime)).ToString();
			}
		}
		public string StopTimeEnabled
		{
			get { return stopTimeEnabled;}
		set 
			{ 
				stopTimeEnabled = value;
			}
		}

		public string StopDate
		{
			get { return stopDate; }
			set { stopDate = value; }
		}
		public string StopTime
		{
			get { return stopTime; }
			set { stopTime = value; }
		}
		public int Count
		{
			get {return jobs.Count;}
		}
		#endregion Properties
		
		#region Helper Methods File Handling
		
		// File-Handling benötigt die "using System.IO" Direktive!
		// Pfad-Angaben für iX-Panel Speicher
		// Internal Flash:			\FlashDrive\
		// FTP System:				\FlashDrive\Project\Project Files\
		// USB-Stick:				\Hard Disk\	
		// SD Card:					\Storage Card\
		
		/// <summary>
		/// SdCardPresent
		/// Returns if a SD Card (Flash Memory) is inserted in the Panel
		/// </summary>
		/// <returns>bool</returns>
		public bool SdCardExists()
		{
			string path = @"\Storage Card";
			
			// Determine whether the SD Flash Card is inserted. 
			if (Directory.Exists(path)) 
				return true;
			else
				return false;	
		}
		public bool UsbStickExists()
		{
			string path = @"\Hard Disk\";
			
			// Determine whether a USB Memory Device is connected. 
			if (Directory.Exists(path)) 
				return true;
			else
				return false;	
		}		
		#endregion Helper Methods File Handling	
	}
	
}
